@@ -4,7 +4,7 @@ import os
 import sys
 
 sys.path.insert(0, os.path.abspath('.'))
-extensions = ['test_enumerable_node']
+extensions = ['enumerable_node']
 
 master_doc = 'index'
 numfig = True
